@@ -1,18 +1,22 @@
 import logging
 import os
-import sys
+import tempfile
+import shutil
+from PIL import Image
+from pathlib import Path
+import glob
 
 logger = logging.getLogger("examples")
 
 
-class Examples():
+class Examples:
     """runs pyami with various examples of commands
 
     experimental
     """
 
     def __init__(self, pyamix=None):
-#        self.pyamix = pyamix if pyamix is not None else PyAMI()
+        # self.pyamix = pyamix if pyamix is not None else PyAMI()
         self.logger = logger
         self.pyamix = pyamix
 
@@ -26,6 +30,19 @@ class Examples():
         debugs symbols"""
         self.pyamix.commandline("--debug symbols")
 
+    def setup(self):
+        proj_dir = Path(Path(__file__).parent, "resources/projects/oil4")
+
+        assert os.path.exists(proj_dir), "path {proj_dir}"
+        self.test_copy_dir = tempfile.TemporaryDirectory().name
+        shutil.copytree(proj_dir, self.test_copy_dir)
+        print(f"copy_dir {self.test_copy_dir}")
+        return proj_dir
+
+    def teardown(self):
+        if os.path.exists(self.test_copy_dir):
+            shutil.rmtree(self.test_copy_dir)
+
     def example_copy(self):
         self.pyamix.run_command([
             "--copy", "${examples_test.p}", "${temp_dir}/examples", "overwrite",
@@ -47,10 +64,13 @@ class Examples():
         creates a globbed list of filenames
         then iterates through this and identifies and writes list of files to named path
         """
+        # self.setup()
         self.pyamix.run_command(
             "--proj ${examples_test.p} --glob ${examples_test.p}/**/sections/**/*fig.xml" \
+            # f"--proj {self.test_copy_dir} --glob {self.test_copy_dir}/**/sections/**/*fig.xml" \
             # " --outfile _figures/fig0.txt"
         )
+        # self.teardown()
 
     def example_glob00(self):
         """ globs abstracts
@@ -93,16 +113,23 @@ class Examples():
     # "--config", # defaults to config.ini.master,~/pyami/config.ini.master if omitted
 
     # on the commandline:
-    # python physchem/python/pyamix.py --proj '${oil26.p}' --glob '${proj}/**/sections/**/*abstract.xml' --dict '${eo_plant.d}' '${ov_country.d}' --apply xml2txt --combine concat_str --outfile '${proj}/files/shweata_1.txt'
+    # python physchem/python/pyamix.py --proj '${oil26.p}' --glob '${proj}/**/sections/**/*abstract.xml'
+    # --dict '${eo_plant.d}' '${ov_country.d}' --apply xml2txt --combine concat_str
+    # --outfile '${proj}/files/shweata_1.txt'
     # whihc expands to
-    # python physchem/python/pyamix.py --apply xml2txt --combine concat_str --dict '/Users/pm286/projects/CEVOpen/dictionary/eoPlant/eo_plant.xml' '/Users/pm286/dictionary/openvirus20210120/country/country.xml' --glob '/Users/pm286/projects/openDiagram/physchem/resources/oil26/**/sections/**/*abstract.xml' --outfile '/Users/pm286/projects/openDiagram/physchem/resources/oil26/files/shweata_1.txt' --proj '/Users/pm286/projects/openDiagram/physchem/resources/oil26'
+    # python physchem/python/pyamix.py --apply xml2txt --combine concat_str
+    # --dict '/Users/pm286/projects/CEVOpen/dictionary/eoPlant/eo_plant.xml'
+    # '/Users/pm286/dictionary/openvirus20210120/country/country.xml' -
+    # -glob '/Users/pm286/projects/openDiagram/physchem/resources/oil26/**/sections/**/*abstract.xml'
+    # --outfile '/Users/pm286/projects/openDiagram/physchem/resources/oil26/files/shweata_1.txt'
+    # --proj '/Users/pm286/projects/openDiagram/physchem/resources/oil26'
 
     def example_xml2sect(self):
 
         self.banner(self.example_xml2sect.__name__)
 
         proj_dir = self.pyamix.get_symbol("examples_test.p")
-        print("path", proj_dir, os.path.exists(proj_dir))
+        print("path", proj_dir, Path(proj_dir).exists())
         # split into sections
         self.pyamix.run_command([
             "--proj", proj_dir,
@@ -111,8 +138,18 @@ class Examples():
             "--assert", "file_glob_count(${examples_test.p}/*/sections/**/*.xml,291)"
         ])
 
+    def example_xml2sect_cmd(self):  # not yet running
+
+        proj_dir = self.setup()
+        print("path", proj_dir, os.path.exists(proj_dir))
+        # split into sections
+        cmd = f"python -m py4ami.pyami --proj {proj_dir} --split xml2sect"
+        os.system(cmd)
+        self.teardown()
+
     def example_split_pdf_txt_paras(self):
-        self.logger.loglevel = logging.DEBUG
+        self.setup()
+#        self.logger.loglevel = logging.DEBUG
         self.banner(self.example_split_pdf_txt_paras.__name__)
 
         proj_dir = self.pyamix.get_symbol("examples_test.p")
@@ -124,10 +161,11 @@ class Examples():
             "--outfile", "fulltext.pdf.sec.txt",
             "--assert", "file_glob_count(${examples_test.p}/*/fulltext.pdf.sec.txt,291)"
         ])
+        self.teardown()
 
     def example_split_sentences(self):
         self.banner(self.example_split_sentences.__name__)
-        self.logger.loglevel = logging.DEBUG
+#        self.logger.loglevel = logging.DEBUG
         proj_dir = self.pyamix.get_symbol("examples_test.p")
         print("path", proj_dir, os.path.exists(proj_dir))
         self.pyamix.run_command([
@@ -186,7 +224,7 @@ class Examples():
             # plants
             # SELECT ?item ?itemLabel
             # WHERE {?item wdt: P225 "Ocimum sanctum".
-            # SERVICE wikibase: label {bd: serviceParam wikibase: language "[AUTO_LANGUAGE],en".}
+            # SERVICE wikibase: label_xml {bd: serviceParam wikibase: language "[AUTO_LANGUAGE],en".}
             # }
             # "wiki_sparql(read sparql_query"Qxxx for plant_species")"
             # "--update(eo_plant.d),"
@@ -248,7 +286,8 @@ class Examples():
             "pd": (self.example_pdf2txt, "convert pdf to text"),
             "pa": (self.example_split_pdf_txt_paras, "split pdf text into paragraphs"),
             "sc": (self.example_xml2sect, "split xml into sections"),
-            "sl": (self.example_split_oil26, "split oil26 project into sections"),
+            "scd": (self.example_xml2sect_cmd(), "split xml into sections using cmd"),
+            #             "sl": (self.example_split_oil26, "split oil4 project into sections"),
             "se": (self.example_split_sentences, "split text to sentences"),
             "sp": (self.example_filter_species, "extract species with italics and regex (not finalised)"),
             "sr": (self.example_search, "search with dictionaries (NYI)"),
@@ -288,11 +327,6 @@ class Examples():
                     f"unknown example: {example}\nchoose from: {example_dict.keys()}")
 
     def transform_img_to_png(self, file):
-        from io import BytesIO
-        from PIL import Image
-        from pathlib import Path
-        import io
-        import binascii
 
         outfile = Path(file + ".png")  # change this
         print(f"path: {outfile}")
@@ -316,8 +350,6 @@ class Examples():
 
     def transform_images_to_png(self):
         """These images are from pdfminer3 - they can't be parsed"""
-        import glob
-        from py4ami.file_lib import Globber
         globstr = "/Users/pm286/misc/images/*.img"
         files = glob.glob(globstr)
         # files = Globber(globstr).get_globbed_files()
@@ -330,17 +362,23 @@ from io import BytesIO
 
 imagefile = BytesIO()
 animage.save(imagefile, format='PNG')
-imagedata = imagefile.getvalue()"""
+imagedata = imagefile.getvalue()
+"""
 
 
 def main():
     from py4ami.pyamix import PyAMI
     examples = Examples(PyAMI())
     # examples.example_help()
-    examples.run_examples(["all"])
+    # examples.run_examples(None)
+    # examples.run_examples(["all"])
+    # examples.run_examples(["g0"])
     # examples.run_examples(["gl"])
+#    examples.run_examples(["sc"]) # works
+    examples.run_examples(["scd"])
     # examples.example_symbols()
     # examples.example_pdf2txt()
+    # examples.run_examples(["sc"])
     # examples.transform_images_to_png() # fails
     # examples.logger.warning(f"calling examples directory will be phased out")
     # print(f" examples args: {sys.argv}")
