@@ -2,13 +2,11 @@ import logging
 logging.debug("loading pdfreader.py")
 # https://stackoverflow.com/questions/56494070/how-to-use-pdfminer-six-with-python-3
 
-from pdfminer3.layout import LAParams, LTTextBox
+from pdfminer3.layout import LAParams
 from pdfminer3.pdfpage import PDFPage
 from pdfminer3.pdfinterp import PDFResourceManager
 from pdfminer3.pdfinterp import PDFPageInterpreter
-from pdfminer3.converter import PDFPageAggregator
 from pdfminer3.converter import TextConverter
-from pdfminer3.converter import XMLConverter
 from pdfminer3.image import ImageWriter
 import io
 
