@@ -8,19 +8,18 @@ import pprint
 from collections import Counter
 import traceback
 from pathlib import Path
-import shutil
 import argparse
 
-from py4ami.dict_lib import AmiDictionary
-from py4ami.examples import Examples
-from py4ami.file_lib import FileLib
-from py4ami.xml_lib import XmlLib
-from test.test_file import TestFile
-from py4ami.text_lib import TextUtil, DSLParser
-from py4ami.pdfreader import PdfReader
-from py4ami.symbol import SymbolIni
-from py4ami.util import AmiLogger
-from py4ami.wikimedia import WikidataLookup
+from .dict_lib import AmiDictionary
+from .examples import Examples
+from .file_lib import FileLib
+from .xml_lib import XmlLib
+from .text_lib import TextUtil, DSLParser
+from .pdfreader import PdfReader
+from .symbol import SymbolIni
+from .util import AmiLogger
+from .wikimedia import WikidataLookup
+from .ami_sections import AMIAbsSection
 
 logging.debug("loading pyamix.py")
 logging.warning(Path(__file__))
@@ -91,7 +90,7 @@ class PyAMI:
         self.current_file = None
         self.fileset = None
         # self.file_dict = {}  # possibly to be replaced by content_store.file_dict
-        self.content_store = ContentStore(self) # will expose content_store.file_dict
+        self.content_store = ContentStore(self)  # will expose content_store.file_dict
         self.func_dict = {}
         self.result = None
         self.set_flags()
@@ -102,8 +101,8 @@ class PyAMI:
         self.set_funcs()
         self.show_symbols = False
         self.ami_dictionary = None
-        self.proj = None # current project in searches
-        self.current_ctree = None # current ctree (may change during iteration
+        self.proj = None  # current project in searches
+        self.current_ctree = None  # current ctree (may change during iteration
         # self.ami_logger = None
         if self.show_symbols:
             pprint.pp(f"SYMBOLS\n {self.symbol_ini.symbols}")
@@ -136,11 +135,12 @@ class PyAMI:
         parser = argparse.ArgumentParser(
             description='Search sections with dictionaries and patterns')
         apply_choices = [self.PDF2TXT, self.TXT2SENT, self.XML2TXT]
-        self.logger.debug("ch", apply_choices)
+        self.logger.debug(f"ch {apply_choices}")
         parser.add_argument('--apply', nargs="+",
                             #                            choices=['pdf2txt', 'txt2sent', 'xml2txt'],
                             choices=apply_choices,
-                            help='list of sequential transformations (1:1 map) to apply to pipeline ({self.TXT2SENT} NYI)')
+                            help='list of sequential transformations (1:1 map) to apply to pipeline '
+                                 '({self.TXT2SENT} NYI)')
         parser.add_argument('--assert', nargs="+",
                             help='assertions; failure gives error message (prototype)')
         parser.add_argument('--combine', nargs=1,
@@ -186,9 +186,10 @@ class PyAMI:
                             help='sections to search; _help gives all(?)')
         parser.add_argument('--split', nargs="+", choices=['txt2para', 'xml2sect'],  # split fulltext.xml,
                             help='split fulltext.* into paras, sections')
-        parser.add_argument('--test', nargs="*",
-                            choices=TestFile.OPTIONS,  # tests and/or setup/teardown
-                            help='run tests for modules; no selection runs all')
+        # parser.add_argument('--test', nargs="*",
+        #                     choices=TestFile.OPTIONS,  # tests and/or setup/teardown
+        #                     help='run tests for modules; no selection runs all')
+        # TODO should tests be run from this menu
         return parser
 
     def commandline(self, commandline: str) -> None:
@@ -200,7 +201,6 @@ class PyAMI:
             arglist = commandline.split(" ")
             self.run_command(arglist)
 
-
     def run_commands(self, arglistlist):
         """runs a list of commands
 
@@ -298,14 +298,14 @@ class PyAMI:
             self.logger.warning(f"COPY {self.args[self.COPY]}")
             self.copy_files()
 
-        
         if self.PROJ in self.args:
             if self.SECT in self.args or self.GLOB in self.args or self.SPLIT in self.args:
                 self.run_project_workflow()
 
-        elif TestFile.TEST in self.args:
-            self.logger.warning(f"TEST in **args {self.args}")
-            TestFile.run_arg_tests(self.args)
+        # elif TestFile.TEST in self.args:
+        #     self.logger.warning(f"TEST in **args {self.args}")
+        #     TestFile.run_arg_tests(self.args)
+        # TODO linkup with test arguments
 
     def replace_single_values_in_self_args_with_list(self, key):
         """always returns list even for single arg
@@ -351,7 +351,7 @@ class PyAMI:
         elif isinstance(old_val, str):
             new_val = self.symbol_ini.replace_symbols_in_arg(old_val)
             if "${" in new_val:
-                raise ValueError (f"Unresolved reference : {new_val}")
+                raise ValueError(f"Unresolved reference : {new_val}")
                 # print("=====================")
                 # self.symbol_ini.print_symbols()
                 # print("=====================")
@@ -417,7 +417,7 @@ class PyAMI:
                 loglevel = str(loglevel)
             if loglevel is not None and loglevel.lower() in levels:
                 level = levels[loglevel.lower()]
-                self.logger.setLevel(level)
+                self.logger.loglevel = level
 
     def run_project_workflow(self):
         """ run when PROJ is set"""
@@ -431,8 +431,9 @@ class PyAMI:
             self.hit_counter = Counter()
             self.run_proj()
             self.logger.debug(f"hit counter: {self.hit_counter}")
-        if self.args[self.TEST]:
-            TestFile.run_arg_tests(self.args)
+        # if self.args[self.TEST]:
+        #     TestFile.run_arg_tests(self.args)
+        # TODO fix tests
         # else:
         #     self.logger.error("{self.args} requires --proj or --test")
         return
@@ -473,7 +474,8 @@ class PyAMI:
 
         Args:
             src (str): path or dirx to copy, must exist
-            dest (str): destination must be a directory. If path becomes a child of <to>; if a directory creates or replaces <to>
+            dest (str): destination must be a directory. If path becomes a child of <to>; if a
+            directory creates or replaces <to>
             overwrite (bool, optional): whether to overwrite if path exists. Defaults to False.
         Exceptions:
             FileNotFoundError: if src does not exist, or dest cannot be created
@@ -563,18 +565,23 @@ class PyAMI:
         file_keys = self.content_store.keys()
         for file in file_keys:
             suffix = FileLib.get_suffix(file)
-            if ".xml" == suffix or type == self.XML2SECT:
-                self.make_xml_sections(file)
+            if ".xml" == suffix and type == self.XML2SECT:
+                # self.make_xml_sections(file)
+                force = False
+                force = True
+                outdir = Path(Path(file).parent, "sections")
+                AMIAbsSection.make_xml_sections(file, outdir, force)
             elif ".txt" == suffix or type == self.TXT2PARA:
                 self.make_text_sections(file)
             else:
                 self.logger.warning(f"no match for suffix: {suffix}")
 
-    def make_xml_sections(self, file):
+    @classmethod
+    def make_xml_sections(cls, file):
         xml_libx = XmlLib()
         xml_libx.logger.setLevel(logging.DEBUG)
-        _ = xml_libx.read(file)
-        xml_libx.make_sections("sections")
+        xml_libx.read(file)
+        xml_libx.make_sections("sections", )
 
     def make_text_sections(self, file):
         sections = []
@@ -783,7 +790,7 @@ class PyAMI:
         DO WE NEED TO STORE THIS?
         """
         data = None
-        self.ami_logger.info(f"reading string content from {file}")
+        self.logger.info(f"reading string content from {file}")
         with open(file, "r", encoding="utf-8") as f:
             try:
                 data = f.read()
@@ -814,17 +821,17 @@ class PyAMI:
         :param func: 
 
         """
-        for file in self.content_store.keys():
-            data = self.content_store(file)
-            self.logger.debug(f"path: {file} => {func_tuple[0]}")
-            new_file = self.create_file_name(file, func_tuple[1])
-
-            try:
-                new_data = func_tuple[0](data)
-                self.store_or_write_data(file, new_data, new_file)
-            except Exception as pdferr:
-                self.logger.warning(
-                    f"cannot read PDF {file} because {pdferr} (probably not a PDF), skipped")
+        # for file in self.content_store.keys():
+        #     data = self.content_store(file)
+        #     self.logger.debug(f"path: {file} => {func_tuple[0]}")
+        #     new_file = self.create_file_name(file, func_tuple[1])
+        #
+        #     try:
+        #         new_data = func_tuple[0](data)
+        #         self.store_or_write_data(file, new_data, new_file)
+        #     except Exception as pdferr:
+        #         self.logger.warning(
+        #             f"cannot read PDF {file} because {pdferr} (probably not a PDF), skipped")
         return
 
     # needs fixing
@@ -837,7 +844,7 @@ class PyAMI:
         if file in self.content_store.file_dict:
             old_data = self.content_store.file_dict[file]
             if old_data is not None and old_data != data:
-                self.ami_logger.warning(
+                self.logger.warning(
                     f"===============================\n"
                     f"=========OVERWRITING data for {file}\n"
                     f"{self.content_store.file_dict[file]} \n========WITH======\n"
@@ -911,7 +918,7 @@ class PyAMI:
         return True if self.flag_dict.get(flag) else False
 
 
-class ContentStore():
+class ContentStore:
     """holds path-related content
 
     replaces earlier py4ami.file_dict
@@ -944,8 +951,10 @@ def main():
     """
 
     run_dsl = False
-    run_tests = False
+    run_tests = False  # needs re-implementing
     run_commands = True
+#    run_commands = False
+#    run_tests = True
 
     PyAMI.logger.warning(
         f"\n============== running pyami main ===============\n{sys.argv[1:]}")
