@@ -1,14 +1,11 @@
 import logging
-# from logging import Level
 import os
 import sys
 import configparser
 import urllib.request
-import re
-from py4ami.file_lib import FileLib
-from py4ami.util import Util
 from pathlib import Path
 
+from .file_lib import FileLib
 
 
 class SymbolIni:
@@ -103,7 +100,7 @@ class SymbolIni:
     def get_code_dir(self, config_file):
         home = os.path.expanduser("~")
         file = __file__
-        print ("FILE ", file)
+        print("FILE ", file)
         return file
 
     def apply_config_file(self, file):
@@ -205,7 +202,7 @@ assumes value
                 self.logger.debug(f"Replaced local symbols")
                 new_value = self.replace_symbols_in_arg(new_value)
 
-            if not key in self.symbols:
+            if key not in self.symbols:
                 self.symbols[key] = new_value
                 self.logger.debug(f"added symbol: {key} => {new_value}")
             elif self.symbols[key] != new_value:
