@@ -1,7 +1,6 @@
-
-import logging
 import os
-from py4ami.xml_lib import XmlLib
+
+from .xml_lib import XmlLib
 
 
 class Text_XML:
