@@ -1,12 +1,8 @@
 """tests in a single path
 This is until I or someone else can figure out relative imports
 """
-import os
-from pathlib import Path
+import unittest
 from glob import glob
-from braceexpand import braceexpand
-import sys
-from SPARQLWrapper import SPARQLWrapper
 import os
 from pathlib import Path
 from lxml import etree
@@ -17,7 +13,10 @@ from py4ami.wikimedia import WikidataSparql as WS
 from py4ami.file_lib import BraceGlobber as bg
 from py4ami.xml_lib import XmlLib
 
+skip_config_test = True
 
+# TODO needs local config file
+@unittest.skipIf(skip_config_test, "needs local config")
 def tests():
     AmiConfig.test_dicts()
 
@@ -73,7 +72,7 @@ class WikimediaTests:
         WHERE 
         {
           ?researchcouncil wdt:P31 wd:Q10498148.
-          SERVICE wikibase:label { bd:serviceParam wikibase:language "[AUTO_LANGUAGE],en". }
+          SERVICE wikibase:label_xml { bd:serviceParam wikibase:language "[AUTO_LANGUAGE],en". }
         }"""
 
         results = WS.get_results_xml(query)
